@@ -18,7 +18,7 @@
 #include <stddef.h>
 
 /* Common audio encoding specification, including a macro for getting
- *  size of encodined samples in bytes. Said macro is still hardcoded
+ *  size of encoded samples in bytes. Said macro is still hardcoded
  *  into out123_encsize(). Relying on this one may help an old program
  *  know sizes of encodings added to fmt123.h later on.
  *  If you don't care, just use the macro.
@@ -29,8 +29,9 @@
  * This should be incremented at least each time a new symbol is added
  * to the header.
  */
-#define OUT123_API_VERSION 1
+#define OUT123_API_VERSION 3
 
+#ifndef MPG123_EXPORT
 /** Defines needed for MS Visual Studio(tm) DLL builds.
  * Every public function must be prefixed with MPG123_EXPORT. When building 
  * the DLL ensure to define BUILD_MPG123_DLL. This makes the function accessible
@@ -50,6 +51,7 @@
 #define MPG123_EXPORT
 #endif
 #endif
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -110,6 +112,13 @@ enum out123_parms
  * The value returned by out123_getparam() might be different if the audio
  * backend changed it (to be unique among clients, p.ex.).
  * TODO: The name provided here is used as prefix in diagnostic messages. */
+,	OUT123_BINDIR /**< string, path to a program binary directory to use
+ * as starting point in the search for the output module directory
+ * (e.g. ../lib/mpg123 or ./plugins). The environment variable MPG123_MODDIR
+ * is always tried first and the in-built installation path last.
+ */
+,	OUT123_ADD_FLAGS /**< enable given flags */
+,	OUT123_REMOVE_FLAGS /**< disable diven flags */
 };
 
 /** Flags to tune out123 behaviour */
@@ -118,17 +127,18 @@ enum out123_flags
 	OUT123_HEADPHONES       = 0x01 /**< output to headphones (if supported) */
 ,	OUT123_INTERNAL_SPEAKER = 0x02 /**< output to speaker (if supported) */
 ,	OUT123_LINE_OUT         = 0x04 /**< output to line out (if supported) */
-,	OUT123_QUIET               = 0x08 /**< no printouts to standard error */
-,	OUT123_KEEP_PLAYING        = 0x10 /**<
+,	OUT123_QUIET            = 0x08 /**< no printouts to standard error */
+,	OUT123_KEEP_PLAYING     = 0x10 /**<
  *  When this is set (default), playback continues in a loop when the device
  *  does not consume all given data at once. This happens when encountering
  *  signals (like SIGSTOP, SIGCONT) that cause interruption of the underlying
  *  functions.
  *  Note that this flag is meaningless when the optional buffer is employed,
  *  There, your program will always block until the buffer completely took
- *  over the data given to it via out123_play(), unless a communcation error
+ *  over the data given to it via out123_play(), unless a communication error
  *  arises.
  */
+,	OUT123_MUTE             = 0x20 /**< software mute (play silent audio) */
 };
 
 /** Read-only output driver/device property flags (OUT123_PROPFLAGS). */
@@ -158,6 +168,13 @@ out123_handle *out123_new(void);
 MPG123_EXPORT
 void out123_del(out123_handle *ao);
 
+/** Free plain memory allocated within libout123.
+ *  This is for library users that are not sure to use the same underlying
+ *  memory allocator as libout123. It is just a wrapper over free() in
+ *  the underlying C library.
+ */
+MPG123_EXPORT void out123_free(void *ptr);
+
 /** Error code enumeration
  * API calls return a useful (positve) value or zero (OUT123_OK) on simple
  * success. A negative value (-1 == OUT123_ERR) usually indicates that some
@@ -182,6 +199,7 @@ enum out123_error
 ,	OUT123_ARG_ERROR /**< some bad function arguments supplied */
 ,	OUT123_BAD_PARAM /**< unknown parameter code */
 ,	OUT123_SET_RO_PARAM /**< attempt to set read-only parameter */
+,	OUT123_BAD_HANDLE /**< bad handle pointer (NULL, usually) */
 ,	OUT123_ERRCOUNT /**< placeholder for shaping arrays */
 };
 
@@ -194,6 +212,8 @@ MPG123_EXPORT
 const char* out123_strerror(out123_handle *ao);
 
 /** Get the plain errcode intead of a string.
+ * Note that this used to return OUT123_ERR instead of
+ * OUT123_BAD_HANDLE in case of ao==NULL before mpg123-1.23.5 .
  * \param ao handle
  * \return error code recorded in handle or OUT123_BAD_HANDLE
  */
@@ -493,7 +513,7 @@ void out123_stop(out123_handle *ao);
  *  Also note that it is no accident that the buffer parameter is not marked
  *  as constant. Some output drivers might need to do things like swap
  *  byte order. This is done in-place instead of wasting memory on yet
- *  another copy. 
+ *  another copy. Software muting also overwrites the data.
  * \param ao handle
  * \param buffer pointer to raw audio data to be played
  * \param bytes number of bytes to read from the buffer
@@ -574,7 +594,5 @@ int out123_getformat( out123_handle *ao
 }
 #endif
 
-#undef MPG123_EXPORT
-
 #endif
 
